
class BaseRiskApplicationController < ApplicationController

  protected
  def authorize_global(ctrl = params[:controller], action = params[:action])
    action = {:controller => ctrl, :action => action}
    allowed = User.current.allowed_to?(action , nil , :global => true)
    allowed ? true : deny_access
  end

  protected
  def find_project
    @project = Project.find( params[:project_id] )
    rescue ActiveRecord::RecordNotFound
      render_404
  end

  protected
  def edit( record ,  params , notice_successful, project = nil )
    if request.post? && !params.nil?
       record.attributes = params
       record.project =  project if record.respond_to? :project
       record.author = User.current if record.respond_to? :author


       if record.save
          flash[:notice] = notice_successful

         if project.nil?
           redirect_to :action => 'index'
            else
           redirect_to :action => 'index' , :project_id => project
         end

         return
       end
    end

  end

  protected
  def issues_new( issue_id, obj, project )


    if Issue.exists?( issue_id ) &&
       !obj.issues.exists?( issue_id )

      obj.issues << Issue.find( issue_id )
      obj.save
    end


    redirect_to :action => 'issues_index', :id => obj , :project_id => project
  end

  protected
  def issues_delete( issue_id, obj, project )
    begin
      issue = Issue.find( issue_id )
    rescue ActiveRecord::RecordNotFound
      render_404
      return
    end

    obj.issues.delete( issue  ) #if @project_risk.issues.exists?( params[:issue_id]  )


    redirect_to :action => 'issues_index', :id =>obj , :project_id => project
  end


  protected
  def risks_search

    conditionStm = risk_query_condition
    limit = per_page_option

    @risk_count = Risk.count(:conditions => conditionStm)
    @risk_pages = Paginator.new self, @risk_count, limit, params['page']
    @risks = Risk.find :all, :conditions => conditionStm, :limit  => limit, :offset => @risk_pages.current.offset
  end


  protected
  def risk_query_condition
   
    if has_value_params( @risk_status ) && has_value_params( @risk_category_id )
      ["status=? AND risk_category_id=?", @risk_status , @risk_category_id ]
    elsif has_value_params( @risk_status )
      ["status=? ", @risk_status ]
    elsif has_value_params( @risk_category_id )
      ["risk_category_id=?", @risk_category_id ]
    else
      nil
    end
  end


  protected
  def exist(collection, id)
    for item in collection
      return true if item.id.to_i == id.to_i
    end
    return false
  end


  private
  def has_value_params(val)
    !val.nil? && !val.blank?
  end
end
