#Manages the incidents of a specific project
class ProjectIncidentsController < BaseRiskApplicationController
  menu_item :risks

  before_filter :find_project , :except => [:preview]
  before_filter :find_project_incident , :only => [:update, :destroy, :show, :issues_new, :issues_index, :issues_delete]
  before_filter :require_login
  before_filter :authorize, :except => [:preview]
  verify :method => :post, :only => [:destroy]

  helper :project_risks
  include ProjectRisksHelper

  
  
 
  def index

    @incident_correction_status = ( params[:incident] && has_value_params( params[:incident][:correction_status] ) ? params[:incident][:correction_status] : nil )
    @incident_impact = ( params[:incident] && has_value_params( params[:incident][:impact] ) ? params[:incident][:impact] : nil )

    conditionStm = project_incident_query_condition
    limit = per_page_option

    @incident_count = ProjectIncident.count(:conditions => conditionStm)
    @incident_pages = Paginator.new self, @incident_count, limit, params['page']
    @incidents = ProjectIncident.find :all,:conditions => conditionStm , :limit  => limit,
                                      :offset => @incident_pages.current.offset
                                      #:order => sort_clause, it could be added, but complex

    render :template => 'project_incidents/index.rhtml', :layout => !request.xhr?
  end

  def create
    @incident = ProjectIncident.new
    edit( @incident ,  params[:incident] , l(:notice_successful_create) , @project )
  end

  def destroy
    if @incident.destroy
      flash[:notice] = l(:notice_successful_delete)
    else
      flash[:notice] = l(:notice_unsuccessful_delete)
    end
    redirect_to :action => 'index', :project_id => @project
  end

  def update
    edit( @incident ,  params[:incident] , l(:notice_successful_update) , @project )
  end

  def preview
    @text =  params[:incident][:correction] if params[:incident]
    render :partial => 'common/preview'
  end

  def issues_index
  end

 
  def issues_new
    super( params[:issue][:id] , @incident , @project )
  end


 
  def issues_delete
    super(params[:issue_id], @incident, @project)
  end

  private
 
  def project_incident_query_condition
 

    result = "project_id=#{@project.id} AND"
    result << " correction_status=#{@incident_correction_status} AND" if has_value_params( @incident_correction_status )
    result << " impact=#{@incident_impact} AND" if has_value_params( @incident_impact )    

    result[0,result.length-3]
  end

  def find_project_incident
    @incident = ProjectIncident.find params[:id], :conditions=>"project_id=#{@project.id}"
    rescue ActiveRecord::RecordNotFound
      render_404
  end
end
