
class ProjectRiskStatisticsController < BaseRiskApplicationController
  menu_item :risks

  before_filter :find_project
  before_filter :require_login
  before_filter :authorize

  helper :project_risks
  include ProjectRisksHelper
  include ProjectRiskStatisticsHelper
  include ProjectIncidentsHelper

  def index
    case params[:tab]
      when "risk_impact"      then risk_impact
      when "risk_probability" then risk_probability
      when "risk_status"      then risk_status
      when "risk_category"    then risk_category
      when "incident_status"  then incident_status
      when "incident_impact"  then incident_impact
      else risk_exposure
    end
  end


  private
  def risk_exposure

    risks = ProjectRisk.find :all,
          :conditions=>["project_id = ?",@project.id]

    translations = exposure_level_choices


    data = Array.new
    (0..translations.size-1).each { |i|
      exposure_value = translations[i][1]
      h = {}
      h['value'] = exposure_value
      h['count'] = count_risks_with_exposure(risks, exposure_value)
      data << h
    } unless translations.nil?

    @report_name = l(:risk_exposure_label)
    @rows = compose_rows(data, translations )
  end

  def count_risks_with_exposure( risks, exposure )
    result = 0

    risks.each {|risk|
      result = result + 1 if risk.exposure == exposure
    } unless risks.nil?

    result
  end


  def risk_impact

    sql = "select impact as value, count(id) as count
             from #{ProjectRisk.table_name}
            where project_id=#{@project.id}
         group by impact"

    data = ActiveRecord::Base.connection.select_all(sql)

    translations = level_choices

    @report_name = l(:risk_impact_label)
    @rows = compose_rows(data, translations )
  end


  def risk_probability

    sql = "select  probability as value, count(id) as count
             from #{ProjectRisk.table_name}
            where project_id=#{@project.id}
         group by probability"

    data = ActiveRecord::Base.connection.select_all(sql)

    translations = level_choices

    @report_name = l(:field_probability)
    @rows = compose_rows(data, translations )
  end


  def risk_status

    sql = "select  mitigation_status as value, count(id) as count
             from #{ProjectRisk.table_name}
            where project_id=#{@project.id}
         group by mitigation_status"

    data = ActiveRecord::Base.connection.select_all(sql)

    translations = mitigation_status_choices

    @report_name = l(:field_mitigation_status)
    @rows = compose_rows(data, translations )
  end


  def risk_category
    sql = "select risk_category_id as value, count(id) as count
             from #{ProjectRisk.table_name}
            where project_id=#{@project.id}
         group by risk_category_id"

    data = ActiveRecord::Base.connection.select_all(sql)

    categories = RiskCategory.find :all, :conditions=>["status = ?", RiskCategory::STATUS_ACTIVE.to_i]

    translations = Array.new

    categories.each { |category|
      translations << [category.name,category.id]
    } unless categories.nil?

    @report_name = l(:risk_category_label)
    @rows = compose_rows(data, translations )
  end


  def incident_status

    sql = "select correction_status as value, count(id) as count
             from #{ProjectIncident.table_name}
            where project_id=#{@project.id}
         group by correction_status"

    data = ActiveRecord::Base.connection.select_all(sql)

    translations = correction_status_choices

    @report_name = l(:field_correction_status)
    @rows = compose_rows(data, translations )

  end


  def incident_impact
    sql = "select impact as value, count(id) as count
             from #{ProjectIncident.table_name}
            where project_id=#{@project.id}
         group by impact"
    data = ActiveRecord::Base.connection.select_all(sql)

    translations = level_choices

    @report_name = l(:incident_impact_label)
    @rows = compose_rows(data, translations )
  end
end
