
class ProjectRisksController < BaseRiskApplicationController
  menu_item :risks

  before_filter :find_project , :except => [:preview, :update_selectable_risks]
  before_filter :find_project_risk , :only => [:update, :destroy, :show, :issues_new, :issues_index, :issues_delete]
  before_filter :require_login
  before_filter :authorize, :except => [:preview , :update_selectable_risks]
  verify :method => :post, :only => [:destroy]

  helper :sort
  include SortHelper


  def index
    @select_categories = RiskCategory.find :all, :conditions=>["status = ?", RiskCategory::STATUS_ACTIVE.to_i]

    @risk_mitigation_status = ( params[:risk] && has_value_params( params[:risk][:mitigation_status] ) ? params[:risk][:mitigation_status] : nil )
    @risk_category_id = ( params[:risk] && has_value_params( params[:risk][:risk_category_id] ) ? params[:risk][:risk_category_id] : nil )
    @risk_probability = ( params[:risk] && has_value_params( params[:risk][:probability] ) ? params[:risk][:probability] : nil )
    
    @risk_impact = ( params[:risk] && has_value_params( params[:risk][:impact] ) ? params[:risk][:impact] : nil )
    @exposure = ( params[:risk] && has_value_params( params[:risk][:exposure] ) ? params[:risk][:exposure] : nil )

    conditionStm = project_risk_query_condition
    limit = per_page_option

    @risk_count = ProjectRisk.count(:conditions => conditionStm)
    @risk_pages = Paginator.new self, @risk_count, limit, params['page']
    @risks = ProjectRisk.find :all, :conditions => conditionStm, :limit  => limit, :offset => @risk_pages.current.offset

    unless @exposure.nil?

     @valid_risks = Array.new

     @risks.each do |risk|
       @valid_risks << risk if risk.exposure == @exposure.to_i
     end

     @risks = @valid_risks
    end

    render :template => 'project_risks/index.rhtml', :layout => !request.xhr?
  end


  def create
    @project_risk = ProjectRisk.new
    edit( l(:notice_successful_create)  )
  end


  def destroy 
    if @project_risk.destroy
      flash[:notice] = l(:notice_successful_delete)
    else
      flash[:notice] = l(:notice_unsuccessful_delete)
    end
    redirect_to :action => 'index', :project_id => @project
  end

  def update
    edit( l(:notice_successful_update) )
  end

  def preview
    if params[:opt] == 'mitigation'
      @text =  params[:project_risk][:mitigation]
    elsif params[:opt] == 'contingency'
      @text =  params[:project_risk][:contingency]
    end

    render :partial => 'common/preview'
  end

  def issues_index
  end


  def issues_new
    super( params[:issue][:id] , @project_risk , @project )
  end


  def issues_delete
    super( params[:issue_id] , @project_risk , @project )
  end

  def update_selectable_risks
    project_risk_id = params[:project_risk_id]
    setSelectableRisks( params[:project_risk_risk_category_id] )
    @project_risk = (project_risk_id.nil? || project_risk_id.blank? ) ? ProjectRisk.new : ProjectRisk.find(project_risk_id.to_i)
    render :partial => 'project_risks/select_risk', :locals => {:f=> @project_risk,  :selectable_risks => @select_risks }
  end

  private

  def setSelectableRisks(risk_category_id)

    @select_risks = Risk.find :all
    
  end

  def edit( notice_successful )
    super( @project_risk ,  params[:project_risk] , notice_successful , @project )

    @select_categories = RiskCategory.find :all, :conditions=>["status = ?", RiskCategory::STATUS_ACTIVE.to_i]

    @project_risk.risk_category = @select_categories.first if @project_risk.risk_category.nil?

    setSelectableRisks( @project_risk.risk_category.id )
  end


  def project_risk_query_condition


    result = "project_id=#{@project.id} AND"
    result << " mitigation_status=#{@risk_mitigation_status} AND" if has_value_params( @risk_mitigation_status )
    result << " risk_category_id=#{@risk_category_id} AND" if has_value_params( @risk_category_id )
    result << " probability=#{@risk_probability} AND" if has_value_params( @risk_probability )
    
    result << " type=#{@risk_type} AND" if has_value_params( @risk_type )
    
    result << " impact=#{@risk_impact} AND" if has_value_params( @risk_impact )

    result[0,result.length-3]
  end

  def find_project_risk
    @project_risk = ProjectRisk.find params[:id], :conditions=>"project_id=#{@project.id}"
    rescue ActiveRecord::RecordNotFound
      render_404
  end
end
