class ProjectRisk < ActiveRecord::Base
  unloadable  # because of http://dev.rubyonrails.org/ticket/8246

  MITIGATION_STATUS_NONE = 0
  MITIGATION_STATUS_ACEITAR = 1
  MITIGATION_STATUS_COMPARTILHAR = 2
  MITIGATION_STATUS_EVITAR = 3  
  MITIGATION_STATUS_EXPLORAR = 4
  MITIGATION_STATUS_MELHORAR = 5
  MITIGATION_STATUS_MITIGAR = 6  
  MITIGATION_STATUS_TRANSFERIR = 7

  belongs_to :project
  belongs_to :author, :class_name => 'User', :foreign_key => 'author_id'
  belongs_to :risk_category
  belongs_to :risk

  has_and_belongs_to_many :issues

  validates_presence_of :project_id , :risk_category_id, :author_id ,:name , :message => "Erro de elemento"
  validates_numericality_of :mitigation_status, :greater_than_or_equal_to=> 0, :less_than_or_equal_to=> 7 , :message => "Tipo de mitigacao invalido"
  validates_numericality_of :probability, :greater_than_or_equal_to=> 0, :less_than_or_equal_to=> 5 , :message => "Probabilidade invalida"
     
  validates_numericality_of :impact, :greater_than_or_equal_to=> 0, :less_than_or_equal_to=> 5 , :message => "Impacto invalido"

  after_create :set_baseline_from_issue
  after_destroy :remove_baseline_issues


  def initialize(args = nil)
    super
    self.mitigation_status =  ProjectRisk::MITIGATION_STATUS_NONE if args.nil? || args[:mitigation_status].nil?
  end

  def exposure
    self.probability + self.impact
  end

  def set_baseline_from_issue
    self.reload
    if EnabledModule.find(:first,:conditions=>["project_id = ? and name = ?",self.project_id,"requirement_tool"]) != nil
      base= get_current_baseline(self.project_id)
      if base!= nil
        bi = BaselineRisks.new
        bi.risk_id = self.id
        bi.baseline_id = base.id
        bi.save
      end
      return true
    end
  end

  def remove_baseline_issues
    if EnabledModule.find(:first,:conditions=>["project_id = ? and name = ?",self.project_id,"requirement_tool"]) != nil
      BaselineRisks.destroy_all(['risk_id = (?)', self.id]) if self.id
    end
  end
end
